@@ -2,4 +2,5 @@
 from .architectures import *
 from .callbacks import *
 from .datasets import *
-from visualisation import *
+from .visualisation import *
+from .weights_init import *
